@@ -22,6 +22,7 @@
 #define KPARTLOADER_H
 
 #include <kparts/mainwindow.h>
+#include <kparts/readonlypart.h>
 
 class KPartLoaderWindow : public KParts::MainWindow
 {
@@ -30,6 +31,9 @@ public:
   KPartLoaderWindow(const QString& partLib);
   virtual ~KPartLoaderWindow();
 
+private slots:
+  void aboutKPart();
+
 private:
   KParts::ReadOnlyPart *m_part;
 };
